@@ -90,17 +90,17 @@ INSERT INTO "message" VALUES('DIPLOMACY_STATUS_NEUTRAL_ALLY',  1, 10.0, NULL);
 INSERT INTO "message" VALUES('DIPLOMACY_STATUS_NEUTRAL_ENEMY', 1, 10.0, NULL);
 INSERT INTO "message" VALUES('DRAG_ROADS_HINT',  1, 20.0, NULL);
 INSERT INTO "message" VALUES('FIELD_NEEDS_FARM', 1, 30.0, NULL);
-INSERT INTO "message" VALUES('MAX_INCR_REACHED', 1, 45.0, NULL);
+INSERT INTO "message" VALUES('MAX_TIER_REACHED', 1, 45.0, NULL);
 INSERT INTO "message" VALUES('MINE_EMPTY',       1, 30.0, NULL);
 INSERT INTO "message" VALUES('MOVE_INVALID_LOCATION', 1, 20.0, NULL);
 INSERT INTO "message" VALUES('MOVE_OUTSIDE_OF_WORLD', 1, 20.0, NULL);
 INSERT INTO "message" VALUES('NEED_MORE_RES',    1, 10.0, NULL);
-INSERT INTO "message" VALUES('NEW_SETTLEMENT',   1, 30.0, 2);
+INSERT INTO "message" VALUES('NEW_SETTLEMENT',   4, 30.0, 2);
 INSERT INTO "message" VALUES('NEW_UNIT',         1, 15.0, 1);
 INSERT INTO "message" VALUES('NEW_WORLD',        1, 15.0, 1);
 INSERT INTO "message" VALUES('NO_MAIN_SQUARE_IN_RANGE', 1, 30.0, NULL);
 INSERT INTO "message" VALUES('QUICKSAVE',        3, 15.0, NULL);
-INSERT INTO "message" VALUES('ROUTE_DISABLED',   1, 45.0, NULL);
+INSERT INTO "message" VALUES('ROUTE_DISABLED',   2, 45.0, NULL);
 INSERT INTO "message" VALUES('SAVED_GAME',       3, 15.0, NULL);
 INSERT INTO "message" VALUES('SCREENSHOT',       2, 20.0, NULL);
 INSERT INTO "message" VALUES('SETTLER_LEVEL_UP', 1, 30.0, 3);
@@ -125,7 +125,7 @@ INSERT INTO "message_text" VALUES('DIPLOMACY_STATUS_NEUTRAL_ENEMY', '{player1} a
 INSERT INTO "message_text" VALUES('DRAG_ROADS_HINT',  'You can also drag roads.');
 INSERT INTO "message_text" VALUES('FIELD_NEEDS_FARM', 'One of your fields requires a farm to harvest its crops.');
 INSERT INTO "message_text" VALUES('MINE_EMPTY',       'Your mine has run out of resources.');
-INSERT INTO "message_text" VALUES('MAX_INCR_REACHED', 'You have reached the current maximum increment. Your inhabitants will not upgrade further.');
+INSERT INTO "message_text" VALUES('MAX_TIER_REACHED', 'You have reached the current maximum tier. Your inhabitants will not upgrade further.');
 INSERT INTO "message_text" VALUES('MOVE_INVALID_LOCATION', 'Cannot go here.');
 INSERT INTO "message_text" VALUES('MOVE_OUTSIDE_OF_WORLD', 'Your crew refuses to leave this map.');
 INSERT INTO "message_text" VALUES('NEED_MORE_RES',    'You need more {resource} to build this building.');
@@ -145,15 +145,13 @@ INSERT INTO "message_text" VALUES('YOU_LOST',         'You failed the scenario.'
 
 CREATE TABLE "message_icon" (
 	"icon_id" INT NOT NULL,
-	"up_image" TEXT NOT NULL,
-	"down_image" TEXT NOT NULL,
-	"hover_image" TEXT NOT NULL
+	"path" TEXT NOT NULL
 );
-INSERT INTO "message_icon" VALUES(1, 'content/gui/icons/widgets/messages/msg_letter_n.png', 'content/gui/icons/widgets/messages/msg_letter_d.png', 'content/gui/icons/widgets/messages/msg_letter_h.png');
-INSERT INTO "message_icon" VALUES(2, 'content/gui/icons/widgets/messages/msg_system_n.png', 'content/gui/icons/widgets/messages/msg_system_d.png', 'content/gui/icons/widgets/messages/msg_system_h.png');
-INSERT INTO "message_icon" VALUES(3, 'content/gui/icons/widgets/messages/msg_save_n.png',   'content/gui/icons/widgets/messages/msg_save_d.png',   'content/gui/icons/widgets/messages/msg_save_h.png');
-INSERT INTO "message_icon" VALUES(4, 'content/gui/icons/widgets/messages/msg_anchor_n.png', 'content/gui/icons/widgets/messages/msg_anchor_d.png', 'content/gui/icons/widgets/messages/msg_anchor_h.png');
-INSERT INTO "message_icon" VALUES(5, 'content/gui/icons/widgets/messages/msg_money_n.png',  'content/gui/icons/widgets/messages/msg_money_d.png',  'content/gui/icons/widgets/messages/msg_money_h.png');
+INSERT INTO "message_icon" VALUES(1, 'icons/widgets/messages/msg_letter');
+INSERT INTO "message_icon" VALUES(2, 'icons/widgets/messages/msg_system');
+INSERT INTO "message_icon" VALUES(3, 'icons/widgets/messages/msg_save');
+INSERT INTO "message_icon" VALUES(4, 'icons/widgets/messages/msg_anchor');
+INSERT INTO "message_icon" VALUES(5, 'icons/widgets/messages/msg_money');
 
 CREATE TABLE "ai" (
 	"client_id" TEXT NOT NULL,
