@@ -1,6 +1,17 @@
 #!/bin/bash
 
-RELEASE_VERSION=2013.1b
+if [ "z" -ne "z${1}"]; then
+    RELEASE_VERSION=${1}
+else
+    RELEASE_VERSION=2013.2
+fi
+
+if [ "z" -ne "z${2}"]; then
+    BUILD_DIR=${2}/build_$(date +%Y%m%d%H%M)/unknown-horizons
+else
+    RELEASE_VERSION=2013.2
+fi
+
 
 BUILD_DIR="../../build/build_$(date +%Y%m%d%H%M)/unknown-horizons"
 echo "Creating build folder: $BUILD_DIR"
