@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -76,7 +76,7 @@ from goal.settlementgoal import SettlementGoal
 from goal.donothing import DoNothingGoal
 
 from horizons.scheduler import Scheduler
-from horizons.messaging import SettlementRangeChanged
+from horizons.messaging import SettlementRangeChanged, NewDisaster, MineEmpty
 from horizons.util.python import decorators
 from horizons.util.python.callback import Callback
 from horizons.util.worldobject import WorldObject
@@ -106,8 +106,7 @@ class AIPlayer(GenericAI):
 		""" Start the AI tick process. Try to space out their ticks evenly. """
 		ai_players = 0
 		position = None
-		for i in xrange(len(self.world.players)):
-			player = self.world.players[i]
+		for player in self.world.players:
 			if isinstance(player, AIPlayer):
 				if player is self:
 					position = ai_players
@@ -154,6 +153,8 @@ class AIPlayer(GenericAI):
 		self.special_domestic_trade_manager = SpecialDomesticTradeManager(self)
 		self.international_trade_manager = InternationalTradeManager(self)
 		SettlementRangeChanged.subscribe(self._on_settlement_range_changed)
+		NewDisaster.subscribe(self.notify_new_disaster)
+		MineEmpty.subscribe(self.notify_mine_empty)
 
 	def get_random_profile(self, token):
 		return BehaviorProfileManager.get_random_player_profile(self, token)
@@ -394,13 +395,16 @@ class AIPlayer(GenericAI):
 	def count_buildings(self, building_id):
 		return sum(settlement_manager.settlement.count_buildings(building_id) for settlement_manager in self.settlement_managers)
 
-	def notify_mine_empty(self, mine):
+	def notify_mine_empty(self, message):
 		"""The Mine calls this function to let the player know that the mine is empty."""
-		self._settlement_manager_by_settlement_id[mine.settlement.worldid].production_builder.handle_mine_empty(mine)
+		settlement = message.mine.settlement
+		if settlement.owner is self:
+			self._settlement_manager_by_settlement_id[settlement.worldid].production_builder.handle_mine_empty(message.mine)
 
 	def notify_new_disaster(self, message):
-		super(AIPlayer, self).notify_new_disaster(message)
-		Scheduler().add_new_object(Callback(self._settlement_manager_by_settlement_id[message.building.settlement.worldid].handle_disaster, message), self, run_in=0)
+		settlement = message.building.settlement
+		if settlement.owner is self:
+			Scheduler().add_new_object(Callback(self._settlement_manager_by_settlement_id[settlement.worldid].handle_disaster, message), self, run_in=0)
 
 	def _on_settlement_range_changed(self, message):
 		"""Stores the ownership changes in a list for later processing."""
@@ -480,6 +484,8 @@ class AIPlayer(GenericAI):
 		assert self._enabled
 		self._enabled = False
 		SettlementRangeChanged.unsubscribe(self._on_settlement_range_changed)
+		NewDisaster.unsubscribe(self.notify_new_disaster)
+		MineEmpty.unsubscribe(self.notify_mine_empty)
 
 	def end(self):
 		assert not self._enabled
