@@ -1,6 +1,6 @@
 # -.- coding: utf-8 -.-
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -60,15 +60,15 @@ class VERSION:
 		return u"<unknown>"
 
 	RELEASE_NAME    = "Unknown Horizons %s"
-	RELEASE_VERSION = u'2013.1b'
+	RELEASE_VERSION = u'2013.2'
 	# change for release:
 	IS_DEV_VERSION = False
-	#RELEASE_VERSION = u'2013.1b'
+	#RELEASE_VERSION = u'2013.2'
 
 	MIN_FIFE_REVISION = 4103
 
 	## +=1 this if you changed the savegame "api"
-	SAVEGAMEREVISION = 70
+	SAVEGAMEREVISION = 71
 
 	@staticmethod
 	def string():
@@ -324,6 +324,7 @@ class VIEW:
 	CELL_IMAGE_DIMENSIONS = (64, 32)
 	ROTATION = 45.0
 	TILT = -60
+	AUTOSCROLL_WIDTH = 10
 
 ## The Production States available in the game sorted by importance from least
 ## to most important
@@ -391,7 +392,7 @@ class TIER:
 	CITIZENS = 3
 	MERCHANTS = 4
 	ARISTOCRATS = 5
-	CURRENT_MAX = 3 # counting starts at 0!
+	CURRENT_MAX = CITIZENS
 
 class SETTLER:
 	TAX_SETTINGS_MIN = 0.5
@@ -477,7 +478,6 @@ class PATHS:
 	ACTION_SETS_DIRECTORY = os.path.join("content", "gfx")
 	TILE_SETS_DIRECTORY = os.path.join("content", "gfx", "base")
 	SAVEGAME_TEMPLATE = os.path.join("content", "savegame_template.sql")
-	ISLAND_TEMPLATE = os.path.join("content", "island_template.sql")
 
 	ATLAS_FILES_DIR = os.path.join("content", "gfx", "atlas")
 	ATLAS_DB_PATH = os.path.join("content", "atlas.sql")
@@ -493,7 +493,6 @@ class PATHS:
 	                                 for d in (
 	                                 "/base",
 	                                 "/buildings",
-	                                 "/buildings_preview",
 	                                 "/misc",
 	                                 "/terrain",
 	                                 "/units",
@@ -516,6 +515,7 @@ class MULTIPLAYER:
 
 class NETWORK:
 	SERVER_ADDRESS = "master.unknown-horizons.org"
+	# change port to 2022 for development server updated after UH commits
 	SERVER_PORT = 2002
 	CLIENT_ADDRESS = None
 	UPDATE_FILE_URL = "http://updates.unknown-horizons.org/current_version.php"
