@@ -1,4 +1,4 @@
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -20,6 +20,8 @@
 
 import itertools
 import json
+import math
+from math import sin, cos
 
 import horizons.globals
 from fife import fife
@@ -29,10 +31,8 @@ from horizons.util.python.decorators import bind_all
 from horizons.util.shapes import Circle, Point, Rect
 from horizons.command.unit import Act
 from horizons.component.namedcomponent import NamedComponent
-from horizons.messaging import MinimapRotationSettingChanged
+from horizons.messaging import SettingChanged
 
-import math
-from math import sin, cos
 
 class Minimap(object):
 	"""A basic minimap.
@@ -59,6 +59,7 @@ class Minimap(object):
 	WAREHOUSE_IMAGE = "content/gui/icons/minimap/warehouse.png"
 	SHIP_NEUTRAL = "content/gui/icons/minimap/ship_neutral.png"
 	SHIP_PIRATE = "content/gui/icons/minimap/pirate.png"
+	GROUND_UNIT_IMAGE = "content/gui/icons/minimap/groundunit.png"
 
 	SHIP_DOT_UPDATE_INTERVAL = 0.5 # seconds
 
@@ -125,12 +126,9 @@ class Minimap(object):
 
 		self.minimap_image = _MinimapImage(self, targetrenderer)
 
-		#import random
-		#ExtScheduler().add_new_object(lambda : self.highlight( (50+random.randint(-50,50), random.randint(-50,50) + 50 )), self, 2, loops=-1)
-
 		self._rotation_setting = horizons.globals.fife.get_uh_setting("MinimapRotation")
 		if self.use_rotation:
-			MinimapRotationSettingChanged.subscribe(self._on_rotation_setting_change)
+			SettingChanged.subscribe(self._on_setting_changed)
 
 	def end(self):
 		self.disable()
@@ -138,7 +136,7 @@ class Minimap(object):
 		self.session = None
 		self.renderer = None
 		if self.use_rotation:
-			MinimapRotationSettingChanged.unsubscribe(self._on_rotation_setting_change)
+			SettingChanged.unsubscribe(self._on_setting_changed)
 
 	def disable(self):
 		"""Due to the way the minimap works, there isn't really a show/hide,
@@ -416,8 +414,8 @@ class Minimap(object):
 		# the path always contains the full path, the unit might be somewhere in it
 		position_of_unit_in_path = 0
 		unit_pos = unit.position.to_tuple()
-		for i in xrange(len(path)):
-			if path[i] == unit_pos:
+		for i, pos in enumerate(path):
+			if pos == unit_pos:
 				position_of_unit_in_path = i
 				break
 
@@ -568,7 +566,7 @@ class Minimap(object):
 			ship_icon = self.imagemanager.load(ship_icon_path)
 			dummy_point1.set(coord[0], coord[1])
 			self.minimap_image.rendertarget.addImage(render_name, dummy_point1, ship_icon)
-			if ship.owner.regular_player is True:
+			if ship.owner.regular_player:
 				# add the 'flag' over the ship icon, with the color of the owner
 				dummy_point0.set(coord[0] - 5, coord[1] - 5)
 				dummy_point1.set(coord[0], coord[1] - 5)
@@ -598,10 +596,10 @@ class Minimap(object):
 			if ship in self.session.selected_instances:
 				self.minimap_image.rendertarget.addPoint(render_name, dummy_point0, *Minimap.COLORS["water"])
 				for x_off, y_off in ((-2,  0),
-					                   (+2,  0),
-					                   ( 0, -2),
-					                   ( 0, +2)):
-					dummy_point1.set(coord[0]+x_off, coord[1] + y_off)
+				                     (+2,  0),
+				                     ( 0, -2),
+				                     ( 0, +2)):
+					dummy_point1.set(coord[0] + x_off, coord[1] + y_off)
 					self.minimap_image.rendertarget.addPoint(render_name, dummy_point1, *color)
 
 		# draw settlement warehouses if something has changed
@@ -638,7 +636,7 @@ class Minimap(object):
 		self.minimap_image.rendertarget.resizeImage(name, p, img, new_width, new_height)
 
 
-	def rotate_right (self):
+	def rotate_right(self):
 		# keep track of rotation at any time, but only apply
 		# if it's actually used
 		self.rotation -= 1
@@ -646,7 +644,7 @@ class Minimap(object):
 		if self._get_rotation_setting():
 			self.draw()
 
-	def rotate_left (self):
+	def rotate_left(self):
 		# see above
 		self.rotation += 1
 		self.rotation %= 4
@@ -671,16 +669,17 @@ class Minimap(object):
 			return False
 		return self._rotation_setting
 
-	def _on_rotation_setting_change(self, message):
-		self._rotation_setting = horizons.globals.fife.get_uh_setting("MinimapRotation")
-		self.draw()
+	def _on_setting_changed(self, message):
+		if message.setting_name == "MinimapRotation":
+			self._rotation_setting = message.new_value
+			self.draw()
 
 	_rotations = { 0 : 0,
 				         1 : 3 * math.pi / 2,
 				         2 : math.pi,
 				         3 : math.pi / 2
 				         }
-	def _get_rotated_coords (self, tup):
+	def _get_rotated_coords(self, tup):
 		"""Rotates according to current rotation settings.
 		Input coord must be relative to screen origin, not minimap origin"""
 		return self._rotate(tup, self._rotations)
@@ -690,10 +689,10 @@ class Minimap(object):
 				              2 : math.pi,
 				              3 : 3 * math.pi / 2
 				              }
-	def _get_from_rotated_coords (self, tup):
+	def _get_from_rotated_coords(self, tup):
 		return self._rotate (tup, self._from_rotations)
 
-	def _rotate (self, tup, rotations):
+	def _rotate(self, tup, rotations):
 		rotation = rotations[ self.rotation ]
 
 		x = tup[0]
