@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -34,7 +34,7 @@ import os.path
 import json
 import traceback
 import threading
-from thread import error as thread_error  # raised by threading.Lock.release
+from thread import error as ThreadError  # raised by threading.Lock.release
 import subprocess
 
 from fife import fife as fife_module
@@ -45,6 +45,7 @@ from horizons.savegamemanager import SavegameManager
 from horizons.gui import Gui
 from horizons.extscheduler import ExtScheduler
 from horizons.constants import AI, GAME, PATHS, NETWORK, SINGLEPLAYER, GAME_SPEED, GFX, VERSION
+from horizons.messaging import LoadingProgress
 from horizons.network.networkinterface import NetworkInterface
 from horizons.util.loaders.actionsetloader import ActionSetLoader
 from horizons.util.loaders.tilesetloader import TileSetLoader
@@ -100,8 +101,8 @@ def start(_command_line_arguments):
 	horizons.globals.fife = Fife()
 
 	if command_line_arguments.generate_minimap: # we've been called as subprocess to generate a map preview
-		from horizons.gui.modules.singleplayermenu import MapPreview
-		MapPreview.generate_minimap( * json.loads(
+		from horizons.gui.modules.singleplayermenu import generate_random_minimap
+		generate_random_minimap( * json.loads(
 		  command_line_arguments.generate_minimap
 		  ) )
 		sys.exit(0)
@@ -109,18 +110,15 @@ def start(_command_line_arguments):
 	if debug: # also True if a specific module is logged (but not 'fife')
 		if not (command_line_arguments.debug_module
 		        and 'fife' not in command_line_arguments.debug_module):
-			horizons.globals.fife._log.lm.setLogToPrompt(True)
-		# After the next FIFE release, we should use this instead which is possible as of r3960:
-		# horizons.globals.fife._log.logToPrompt = True
+			horizons.globals.fife._log.logToPrompt = True
 
 		if command_line_arguments.debug_log_only:
 			# This is a workaround to not show fife logs in the shell even if
 			# (due to the way the fife logger works) these logs will not be
 			# redirected to the UH logfile and instead written to a file fife.log
 			# in the current directory. See #1782 for background information.
-			horizons.globals.fife._log.lm.setLogToPrompt(False)
-			horizons.globals.fife._log.lm.setLogToFile(True)
-			# same as above applies here, use property after next FIFE release
+			horizons.globals.fife._log.logToPrompt = False
+			horizons.globals.fife._log.logToFile = True
 
 	if command_line_arguments.mp_bind:
 		try:
@@ -245,22 +243,24 @@ def start(_command_line_arguments):
 		__string_previewer.show()
 	elif command_line_arguments.create_mp_game:
 		_modules.gui.show_main()
-		_modules.gui.show_multi()
-		_modules.gui.create_default_mp_game()
+		_modules.gui.windows.show(_modules.gui.multiplayermenu)
+		_modules.gui.multiplayermenu._create_game()
+		_modules.gui.windows._windows[-1].act()
 	elif command_line_arguments.join_mp_game:
 		_modules.gui.show_main()
-		_modules.gui.show_multi()
-		_modules.gui.join_mp_game()
+		_modules.gui.windows.show(_modules.gui.multiplayermenu)
+		_modules.gui.multiplayermenu._join_game()
 	else: # no commandline parameter, show main screen
 
-		# initalize update checker
+		# initialize update checker
 		if not command_line_arguments.gui_test:
 			from horizons.util.checkupdates import UpdateInfo, check_for_updates, show_new_version_hint
 			update_info = UpdateInfo()
 			update_check_thread = threading.Thread(target=check_for_updates, args=(update_info,))
 			update_check_thread.start()
+
 			def update_info_handler(info):
-				if info.status == UpdateInfo.UNINITIALISED:
+				if info.status == UpdateInfo.UNINITIALIZED:
 					ExtScheduler().add_new_object(Callback(update_info_handler, info), info)
 				elif info.status == UpdateInfo.READY:
 					show_new_version_hint(_modules.gui, info)
@@ -297,6 +297,9 @@ def quit():
 
 def start_singleplayer(options):
 	"""Starts a singleplayer game."""
+	_modules.gui.show_loading_screen()
+
+	LoadingProgress.broadcast(None, 'load_objects')
 	global preloading
 	preload_game_join(preloading)
 
@@ -305,28 +308,26 @@ def start_singleplayer(options):
 	horizons.globals.fife.engine.pump()
 	horizons.globals.fife.set_cursor_image('default')
 
-	# hide whatever is displayed before the game starts
-	_modules.gui.hide()
-
 	# destruct old session (right now, without waiting for gc)
 	if _modules.session is not None and _modules.session.is_alive:
 		_modules.session.end()
 
 	if options.is_editor:
-		from horizons.editor.gui import IngameGui
+		from horizons.editor.session import EditorSession as session_class
 	else:
-		from horizons.gui.ingamegui import IngameGui
+		from horizons.spsession import SPSession as session_class
 
 	# start new session
-	from horizons.spsession import SPSession
-	_modules.session = SPSession(_modules.gui, horizons.globals.db, ingame_gui_class=IngameGui)
+	_modules.session = session_class(_modules.gui, horizons.globals.db)
 
 	from horizons.scenario import InvalidScenarioFileFormat # would create import loop at top
 	try:
 		_modules.session.load(options)
+		_modules.gui.close_all()
 	except InvalidScenarioFileFormat:
 		raise
 	except Exception:
+		_modules.gui.close_all()
 		# don't catch errors when we should fail fast (used by tests)
 		if os.environ.get('FAIL_FAST', False):
 			raise
@@ -340,8 +341,8 @@ def start_singleplayer(options):
 				traceback.print_exc()
 				print "Additionally to failing when loading, cleanup afterwards also failed"
 		_modules.gui.show_main()
-		headline = _(u"Failed to start/load the game")
-		descr = _(u"The game you selected could not be started.") + u" " +\
+		headline = _("Failed to start/load the game")
+		descr = _("The game you selected could not be started.") + u" " + \
 		        _("The savegame might be broken or has been saved with an earlier version.")
 		_modules.gui.show_error_popup(headline, descr)
 		_modules.gui.load_game()
@@ -351,8 +352,9 @@ def prepare_multiplayer(game, trader_enabled=True, pirate_enabled=True, natural_
 	"""Starts a multiplayer game server
 	TODO: actual game data parameter passing
 	"""
-	global preloading
+	_modules.gui.show_loading_screen()
 
+	global preloading
 	preload_game_join(preloading)
 
 	# remove cursor while loading
@@ -360,9 +362,6 @@ def prepare_multiplayer(game, trader_enabled=True, pirate_enabled=True, natural_
 	horizons.globals.fife.engine.pump()
 	horizons.globals.fife.set_cursor_image('default')
 
-	# hide whatever is displayed before the game starts
-	_modules.gui.hide()
-
 	# destruct old session (right now, without waiting for gc)
 	if _modules.session is not None and _modules.session.is_alive:
 		_modules.session.end()
@@ -383,6 +382,7 @@ def prepare_multiplayer(game, trader_enabled=True, pirate_enabled=True, natural_
 	_modules.session.load(options)
 
 def start_multiplayer(game):
+	_modules.gui.close_all()
 	_modules.session.start()
 
 
@@ -400,7 +400,6 @@ def _start_map(map_name, ai_players=0, is_scenario=False,
 	if not map_file:
 		return False
 
-	_modules.gui.show_loading_screen()
 	options = StartGameOptions.create_start_singleplayer(map_file, is_scenario,
 		ai_players, trader_enabled, pirate_enabled, force_player_id, is_map)
 	start_singleplayer(options)
@@ -421,7 +420,6 @@ def _load_cmd_map(savegame, ai_players, force_player_id=None):
 	if not map_file:
 		return False
 
-	_modules.gui.show_loading_screen()
 	options = StartGameOptions.create_load_game(map_file, force_player_id)
 	start_singleplayer(options)
 	return True
@@ -462,20 +460,17 @@ def _load_last_quicksave(session=None, force_player_id=None):
 	@param session: value of session
 	@return: bool, whether loading succeded"""
 	save_files = SavegameManager.get_quicksaves()[0]
-	if session is not None:
+	if _modules.session is not None:
 		if not save_files:
-			session.gui.show_popup(_("No quicksaves found"),
-			                       _("You need to quicksave before you can quickload."))
+			_modules.session.gui.show_popup(_("No quicksaves found"),
+			                                _("You need to quicksave before you can quickload."))
 			return False
-		else:
-			session.ingame_gui.on_escape() # close widgets that might be open
 	else:
 		if not save_files:
 			print "Error: No quicksave found."
 			return False
 
 	save = max(save_files)
-	_modules.gui.show_loading_screen()
 	options = StartGameOptions.create_load_game(save, force_player_id)
 	start_singleplayer(options)
 	return True
@@ -492,10 +487,6 @@ def _edit_map(map_file):
 
 	options = StartGameOptions.create_editor_load(map_file)
 	start_singleplayer(options)
-
-	from horizons.editor.worldeditor import WorldEditor
-	_modules.session.world_editor = WorldEditor(_modules.session.world)
-	_modules.session.ingame_gui.setup()
 	return True
 
 def edit_map(map_name):
@@ -577,5 +568,5 @@ def preload_game_join(preloading):
 	else:
 		try:
 			lock.release()
-		except thread_error:
+		except ThreadError:
 			pass # due to timing issues, the lock might be released already
