@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -50,6 +50,8 @@ from horizons.component.healthcomponent import HealthComponent
 from horizons.component.storagecomponent import StorageComponent
 from horizons.world.disaster.disastermanager import DisasterManager
 from horizons.world import worldutils
+from horizons.util.savegameaccessor import SavegameAccessor
+from horizons.messaging import LoadingProgress
 
 class World(BuildingOwner, WorldObject):
 	"""The World class represents an Unknown Horizons map with all its units, grounds, buildings, etc.
@@ -82,6 +84,20 @@ class World(BuildingOwner, WorldObject):
 		if False:
 			assert isinstance(session, horizons.session.Session)
 		self.session = session
+
+		# create playerlist
+		self.players = []
+		self.player = None # player sitting in front of this machine
+		self.trader = None
+		self.pirate = None
+
+		# create shiplist, which is currently used for saving ships
+		# and having at least one reference to them
+		self.ships = []
+		self.ground_units = []
+
+		self.islands = []
+
 		super(World, self).__init__(worldid=GAME.WORLD_WORLDID)
 
 	def end(self):
@@ -143,23 +159,20 @@ class World(BuildingOwner, WorldObject):
 			# set on first init
 			self.properties['disasters_enabled'] = disasters_enabled
 
-		# create playerlist
-		self.players = []
-		self.player = None # player sitting in front of this machine
-		self.trader = None
-		self.pirate = None
-
 		self._load_players(savegame_db, force_player_id)
 
 		# all static data
+		LoadingProgress.broadcast(self, 'world_load_map')
 		self.load_raw_map(savegame_db)
 
 		# load world buildings (e.g. fish)
+		LoadingProgress.broadcast(self, 'world_load_buildings')
 		for (building_worldid, building_typeid) in \
 		    savegame_db("SELECT rowid, type FROM building WHERE location = ?", self.worldid):
 			load_building(self.session, savegame_db, building_typeid, building_worldid)
 
 		# use a dict because it's directly supported by the pathfinding algo
+		LoadingProgress.broadcast(self, 'world_init_water')
 		self.water = dict((tile, 1.0) for tile in self.ground_map)
 		self._init_water_bodies()
 		self.sea_number = self.water_body[(self.min_x, self.min_y)]
@@ -182,11 +195,6 @@ class World(BuildingOwner, WorldObject):
 		self.ship_map = {}
 		self.ground_unit_map = {}
 
-		# create shiplist, which is currently used for saving ships
-		# and having at least one reference to them
-		self.ships = []
-		self.ground_units = []
-
 		# create bullets list, used for saving bullets in ongoing attacks
 		self.bullets = []
 
@@ -201,6 +209,7 @@ class World(BuildingOwner, WorldObject):
 				self.pirate = Pirate.load(self.session, savegame_db, pirate_data[0][0])
 
 		# load all units (we do it here cause all buildings are loaded by now)
+		LoadingProgress.broadcast(self, 'world_load_units')
 		for (worldid, typeid) in savegame_db("SELECT rowid, type FROM unit ORDER BY rowid"):
 			Entities.units[typeid].load(self.session, savegame_db, worldid)
 
@@ -214,6 +223,7 @@ class World(BuildingOwner, WorldObject):
 				self.pirate.finish_loading(savegame_db)
 
 			# load the AI stuff only when we have AI players
+			LoadingProgress.broadcast(self, 'world_setup_ai')
 			if any(isinstance(player, AIPlayer) for player in self.players):
 				AIPlayer.load_abstract_buildings(self.session.db) # TODO: find a better place for this
 
@@ -223,6 +233,7 @@ class World(BuildingOwner, WorldObject):
 				if not isinstance(player, HumanPlayer):
 					player.finish_loading(savegame_db)
 
+		LoadingProgress.broadcast(self, 'world_load_stuff')
 		self._load_combat(savegame_db)
 		self._load_diplomacy(savegame_db)
 		self._load_disasters(savegame_db)
@@ -249,20 +260,6 @@ class World(BuildingOwner, WorldObject):
 		if self.session.is_game_loaded():
 			self.diplomacy.load(self, savegame_db)
 
-		# add diplomacy notification listeners
-		def notify_change(caller, old_state, new_state, a, b):
-			player1 = u"%s" % a.name
-			player2 = u"%s" % b.name
-
-			data = {'player1' : player1, 'player2' : player2}
-
-			string_id = 'DIPLOMACY_STATUS_{old}_{new}'.format(old=old_state.upper(),
-			                                                  new=new_state.upper())
-			self.session.ingame_gui.message_widget.add(point=None, string_id=string_id,
-			                                           message_dict=data)
-
-		self.diplomacy.add_diplomacy_status_changed_listener(notify_change)
-
 	def _load_disasters(self, savegame_db):
 		# disasters are only enabled if they are explicitly set to be enabled
 		disasters_disabled = not self.properties.get('disasters_enabled')
@@ -274,7 +271,6 @@ class World(BuildingOwner, WorldObject):
 		self.map_name = savegame_db.map_name
 
 		# load islands
-		self.islands = []
 		for (islandid,) in savegame_db("SELECT DISTINCT island_id + 1001 FROM ground"):
 			island = Island(savegame_db, islandid, self.session, preview=preview)
 			self.islands.append(island)
@@ -467,8 +463,6 @@ class World(BuildingOwner, WorldObject):
 		if pirate_enabled:
 			self.pirate = Pirate(self.session, 99998, "Captain Blackbeard", Color())
 
-		# Fire a message for new world creation
-		self.session.ingame_gui.message_widget.add(point=None, string_id='NEW_WORLD')
 		assert ret_coords is not None, "Return coords are None. No players loaded?"
 		return ret_coords
 
@@ -742,5 +736,13 @@ def load_building(session, db, typeid, worldid):
 	return Entities.buildings[typeid].load(session, db, worldid)
 
 
+def load_raw_world(map_file):
+	WorldObject.reset()
+	world = World(session=None)
+	world.inited = True
+	world.load_raw_map(SavegameAccessor(map_file, True), preview=True)
+	return world
+
+
 decorators.bind_all(World)
 decorators.bind_all(load_building)
