@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -205,13 +205,7 @@ class Island(BuildingOwner, WorldObject):
 		settlement.initialize()
 		settlement.init_buildability_cache(self.terrain_cache)
 		self.add_existing_settlement(position, radius, settlement, load)
-		# TODO: Move this to command, this message should not appear while loading
-		self.session.ingame_gui.message_widget.add(string_id='NEW_SETTLEMENT',
-		                                           point=position.center,
-		                                           message_dict={'player':player.name},
-		                                           play_sound=player.is_local_player)
-
-		NewSettlement.broadcast(self, settlement)
+		NewSettlement.broadcast(self, settlement, position.center)
 
 		return settlement
 
@@ -327,7 +321,7 @@ class Island(BuildingOwner, WorldObject):
 				del self.deposits[building.id][coords]
 		if building.settlement is not None:
 			building.settlement.remove_building(building)
-			assert(building not in building.settlement.buildings)
+			assert building not in building.settlement.buildings
 
 		super(Island, self).remove_building(building)
 		if building.id in self.building_indexers:
